I liked your trick to iterate on chunks to force the compiler to vectorize the code !
Now that the code is properly vectorized, you can add the `mul_add` function, and this time you'll see a significant speedup. I tried it on my machine and it made the code 20% faster.
See the generated assembler here: https://rust.godbolt.org/z/G5A2u0